﻿// OpenProjectFolderInExplorer.cs
//
// Erstellt einen neuen Menüpunkt "Projektordner im Windows-Explorer öffnen" im Hauptmenü "Optionen"
//
// letzte Änderung:
// V1.0.0, 22.02.2010, Frank Schöneck, Projektbeginn
// V1.0.0, 09.11.2012, Frank Schöneck, Umgesetzt von VB.net nach C#
// V2.0.0, 03.09.2018, Frank Schöneck, Fehlerbehandlung durch _eCat_ (http://www.gischel.net/Magic/topic.php?id=714&) hinzugefügt
// V2.1.0, 19.08.2019, Frank Schöneck, Menüpunkt wird nun abhängig vom Menüpunkt "Externe Programme..." eingebunden.
// V2.2.0, 09.07.2020, Frank Schöneck, Aufrufparameter von Exporer.exe verbessert, damit Sonderzeichen keine Probleme machen
//
// Copyright by Frank Schöneck, 2010-2020
//
// für Eplan Electric P8, ab V1.9.11
//

public class OpenProjectFolderInExplorerAction
{
	[DeclareMenu]
	public void MenuFunction()
	{
		Eplan.EplApi.Gui.Menu oMenu = new Eplan.EplApi.Gui.Menu();
		oMenu.AddMenuItem("&Projektordner im Windows-Explorer öffnen", "OpenProjectFolderInExplorerAction", "Es wird der Projektordner im Windows-Explorer geöffnet.", 35005, 1, false, false);
	}

	[DeclareAction("OpenProjectFolderInExplorerAction")]
	public void Action()
	{
		Eplan.EplApi.ApplicationFramework.ActionManager oMngr = new Eplan.EplApi.ApplicationFramework.ActionManager();
		Eplan.EplApi.ApplicationFramework.Action oSelSetAction = oMngr.FindAction("selectionset");
		string sProjectFolder = string.Empty;
		if (oSelSetAction != null)
		{
			Eplan.EplApi.ApplicationFramework.ActionCallingContext ctx = new Eplan.EplApi.ApplicationFramework.ActionCallingContext();
			ctx.AddParameter("TYPE", "PROJECT");
			bool bRet = oSelSetAction.Execute(ctx);
			if (bRet)
			{
				string selectedProject = string.Empty;
				ctx.GetParameter("PROJECT", ref selectedProject);

				if (selectedProject.Contains(".elk"))
				{
					sProjectFolder = selectedProject.Replace(".elk", ".edb");
				}
				else if (selectedProject.Contains(".elr"))
				{
					sProjectFolder = selectedProject.Replace(".elr", ".edb");
				}
				else if (selectedProject.Contains(".ell"))
				{
					sProjectFolder = selectedProject.Replace(".ell", ".edb");
				}
				else { }
			}
			else
			{
				System.Windows.Forms.MessageBox.Show("Ausführen der Action selectionset fehlgeschlagen!");
			}

		}
		else
		{
			System.Windows.Forms.MessageBox.Show("Action selectionset nicht gefunden!");
		}

		System.Diagnostics.ProcessStartInfo proc = new System.Diagnostics.ProcessStartInfo();
		proc.FileName = "explorer.exe";
		proc.Arguments = "\"" + sProjectFolder + "\"";
		System.Diagnostics.Process.Start(proc);
	}

}
